NAME

Statistics::Kappa::Fleiss - Calculate inter-annotator agreement.

VERSION

Version 0.02

SYNOPSIS

use Statistics::Kappa::Fleiss;

my @data = ([0, 0, 0, 0, 14],
            [0, 2, 6, 4, 2],
            [0, 0, 3, 5, 6]);
my $fk = 'Statistics::Kappa::Fleiss'->new(data => \@data);
my $kappa = $fk->kappa;

METHODS

'Statistics::Kappa::Fleiss'->new(data => \@data)

The constructor. It takes a named argument data which should contain an array reference. Each element of the array represents a rated item by another anonymous array, which on position j contains the number of raters that assigned the category j to the item. Therefore, the format of the data is different to other Statistics::Kappa modules.

data

AUTHOR

E. Choroba <choroba@matfyz.cz>

BUGS

Please report any bugs or feature requests to the GitHub repository.

SUPPORT

You can find documentation for this module with the perldoc command.

perldoc Statistics::Kappa::Fleiss

You can also look for information at:

SEE ALSO

Other modules from Statistics::Kappa: Statistics::Kappa::Cohen and Statistics::Kappa::Weighted. Another inter-rater agreement statistics: Statistics::Krippendorff.

LICENSE AND COPYRIGHT

This software is Copyright (c) 2026 by E. Choroba <choroba@matfyz.cz>.

This is free software, licensed under:

The Artistic License 2.0 (GPL Compatible)